@@ -35,7 +35,7 @@ use HTML::Blitz::ActionType qw(
 );
 use List::Util qw(all reduce);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 method new($class:) {
     bless {
@@ -379,7 +379,7 @@ fun _with_stopper($alternatives, $result) {
 }
 
 method compile($name, $html) {
-    my $codegen = HTML::Blitz::CodeGen->new;
+    my $codegen = HTML::Blitz::CodeGen->new(name => $name);
     my $matcher = HTML::Blitz::Matcher->new([
         map _with_stopper($_->{selector}, _bind_scope($codegen->scope, $_->{result})),
             @{$self->{rules}}
